{ config, lib, pkgs, inputs, ... }:

{
  # Simply install just the packages
  environment.packages = with pkgs; [
    # User-facing stuff that you really really want to have
    vim # or some other editor, e.g. nano or neovim
    git

    openssh
    which
    nettools

    # Some common stuff that people expect to have
    iproute2
    procps
    killall
    diffutils
    findutils
    utillinux
    #tzdata
    hostname
    man
    gnugrep
    #gnupg
    #gnused
    gnutar
    #bzip2
    #gzip
    #xz
    #zip
    #unzip
  ];

  # Backup etc files instead of failing to activate generation if a file already exists in /etc
  environment.etcBackupExtension = ".bak";

  # Read the changelog before changing this value
  system.stateVersion = "24.05";

  # Set up nix for flakes
  nix.extraOptions = ''
    experimental-features = nix-command flakes
  '';

  user.shell = "${lib.getExe pkgs.zsh}";

  terminal.colors = {
    background = "#1d2021";
    foreground = "#ebdbb2";
    color0 =  "#282828";
    color8 =  "#928374";
    color1 =  "#cc241d";
    color9 =  "#fb4934";
    color2 =  "#98971a";
    color10 = "#b8bb26";
    color3 =  "#d79921";
    color11 = "#fabd2f";
    color4 =  "#458588";
    color12 = "#83a598";
    color5 =  "#b16286";
    color13 = "#d3869b";
    color6 =  "#689d6a";
    color14 = "#8ec07c";
    color7 =  "#a89984";
    color15 = "#ebdbb2h";
  };

  # Set your time zone
  time.timeZone = "America/Toronto";

  home-manager = {
    extraSpecialArgs = {inherit inputs;};
    config = ./home.nix;
    backupFileExtension = "hm-bak";
    useGlobalPkgs = true;
    useUserPackages = true;
  };
}
